@@ -2,9 +2,11 @@ import abc
 import gzip
 import io
 import logging
+import os
 import tempfile
 import time
 import uuid
+from contextlib import ExitStack
 
 import msgpack
 import numpy as np
@@ -15,16 +17,10 @@ from .spark import fetch_td_spark_context
 
 logger = logging.getLogger(__name__)
 
-if pd.__version__ >= "1.0.0":
-    logger.warning(
-        "You are using pandas 1.0.0 or later, but pytd is not fully tested on "
-        "the major version. Since the version has introduced some "
-        "experimental, backward-incompatible features, there might be a "
-        "chance of unexpected runtime failure when you handle a DataFrame "
-        "containing null or array. See pandas official documentation for more "
-        "information: "
-        "https://pandas.pydata.org/pandas-docs/version/1.0.0/whatsnew/v1.0.0.html"
-    )
+
+def _is_pd_na(x):
+    is_na = pd.isna(x)
+    return isinstance(is_na, bool) and is_na
 
 
 def _is_np_nan(x):
@@ -40,13 +36,20 @@ def _is_0d_nan(x):
 
 
 def _isnull(x):
-    return x is None or _is_np_nan(x)
+    return x is None or _is_np_nan(x) or _is_pd_na(x)
 
 
 def _isinstance_or_null(x, t):
     return _isnull(x) or isinstance(x, t)
 
 
+def _replace_pd_na(dataframe):
+    """Replace np.nan to None to avoid Int64 conversion issue
+    """
+    if dataframe.isnull().any().any():
+        dataframe.replace({np.nan: None}, inplace=True)
+
+
 def _to_list(ary):
     # Return None if None, np.nan, or np.nan in 0-d array given
     if ary is None or _is_np_nan(ary) or _is_0d_nan(ary):
@@ -64,7 +67,7 @@ def _to_list(ary):
     elif kind == "U":
         _ary = np.where(_ary == "nan", None, _ary)
     elif kind == "O":
-        _ary = np.array([None if _is_np_nan(x) else x for x in _ary])
+        _ary = np.array([None if _is_np_nan(x) or _is_pd_na(x) else x for x in _ary])
     return _ary.tolist()
 
 
@@ -98,7 +101,7 @@ def _cast_dtypes(dataframe, inplace=True, keep_list=False):
             t = "Int64" if df[column].isnull().any() else "int64"
         elif kind == "f":
             t = float
-        elif kind == "O":
+        elif kind in ("b", "O"):
             t = object
             if df[column].apply(_isinstance_or_null, args=((list, np.ndarray),)).all():
                 if keep_list:
@@ -108,6 +111,9 @@ def _cast_dtypes(dataframe, inplace=True, keep_list=False):
                         _convert_nullable_str, args=((list, np.ndarray),)
                     )
             elif df[column].apply(_isinstance_or_null, args=(bool,)).all():
+                # Bulk Import API internally handles boolean string as a boolean type,
+                # and hence "True" ("False") will be stored as "true" ("false"). Align
+                # to lower case here.
                 df[column] = df[column].apply(
                     _convert_nullable_str, args=(bool,), lower=True
                 )
@@ -117,12 +123,6 @@ def _cast_dtypes(dataframe, inplace=True, keep_list=False):
                 t = str
         df[column] = df[column].astype(t)
 
-        # Bulk Import API internally handles boolean string as a boolean type,
-        # and hence "True" ("False") will be stored as "true" ("false"). Align
-        # to lower case here.
-        if kind == "b":
-            df[column] = df[column].apply(lambda s: s.lower())
-
     if not inplace:
         return df
 
@@ -313,6 +313,10 @@ class BulkImportWriter(Writer):
         temporary CSV/msgpack file, and upload the file to Treasure Data via bulk
         import API.
 
+        Note:
+            If you pass a dataframe with ``Int64`` column, the column will be converted
+            as ``varchar`` on Treasure Data schema due to BulkImport API restriction.
+
         Parameters
         ----------
         dataframe : :class:`pandas.DataFrame`
@@ -407,21 +411,25 @@ class BulkImportWriter(Writer):
 
         _cast_dtypes(dataframe, keep_list=keep_list)
 
-        if fmt == "csv":
-            fp = tempfile.NamedTemporaryFile(suffix=".csv")
-            dataframe.to_csv(fp.name)
-        elif fmt == "msgpack":
-            fp = io.BytesIO()
-            fp = self._write_msgpack_stream(dataframe.to_dict(orient="records"), fp)
-        else:
-            raise ValueError(
-                "unsupported format '{}' for bulk import. "
-                "should be 'csv' or 'msgpack'".format(fmt)
-            )
+        with ExitStack() as stack:
+            if fmt == "csv":
+                fp = tempfile.NamedTemporaryFile(suffix=".csv", delete=False)
+                stack.callback(os.unlink, fp.name)
+                stack.callback(fp.close)
+                dataframe.to_csv(fp.name)
+            elif fmt == "msgpack":
+                _replace_pd_na(dataframe)
 
-        self._bulk_import(table, fp, if_exists, fmt)
-
-        fp.close()
+                fp = io.BytesIO()
+                fp = self._write_msgpack_stream(dataframe.to_dict(orient="records"), fp)
+                stack.callback(fp.close)
+            else:
+                raise ValueError(
+                    "unsupported format '{}' for bulk import. "
+                    "should be 'csv' or 'msgpack'".format(fmt)
+                )
+            self._bulk_import(table, fp, if_exists, fmt)
+            stack.close()
 
     def _bulk_import(self, table, file_like, if_exists, fmt="csv"):
         """Write a specified CSV file to a Treasure Data table.
@@ -636,9 +644,8 @@ class SparkWriter(Writer):
         from py4j.protocol import Py4JJavaError
 
         _cast_dtypes(dataframe)
-        # Replace np.nan to None to avoid Int64 conversion issue
-        if dataframe.isnull().any().any():
-            dataframe.replace({np.nan: None}, inplace=True)
+        _replace_pd_na(dataframe)
+
         sdf = self.td_spark.spark.createDataFrame(dataframe)
         try:
             destination = "{}.{}".format(table.database, table.table)
